API docs for “spamfighter.core.commands.serialize”

# Module s.c.c.serialize

Part of spamfighter.core.commands View Source

Поддержка сериализации/десериализации для типов данных, передаваемых в командах.

Class | ISerializable | Сущность, которая может передаваться в команде (и, соответственно, должна
Class | SerializerNotFoundException | Не был найден подходящий десериализатор для переданного интерфейса.
Function | register_serializer | Регистрируем класс, который занимается сериализацией интерфейса.
Function | get_serializer | Получить класс, который занимается сериализацией для интерфейса.
Class | DateTime | Наследник datetime.datetime, который требует в конструктор

@registrator
def register_serializer(cls, interface): (source)
Регистрируем класс, который занимается сериализацией интерфейса.

Parameters | interface | сериализуемый интерфейс (type: `ISerializable` )
| serializer | класс, который умеет рассериализовывать объекты для переданного интерфейса

def get_serializer(interface): (source)
Получить класс, который занимается сериализацией для интерфейса.

Parameters | interface | сериализуемый интерфейс (type: `ISerializable` )
Returns | (type: `ISerializable` )